@@ -224,6 +224,8 @@ RCPP_MODULE(spat){
 	    .constructor<std::vector<std::string> >()
 		.constructor<std::vector<unsigned>, std::vector<double>, std::string>()
 
+		.method("copy", &SpatRaster::deepCopy, "deepCopy")
+
 		.method("spatinit", &SpatRaster::spatinit, "init")
 		
 		.method("combineSources", &SpatRaster::combineSources, "combineSources")
@@ -332,18 +334,23 @@ RCPP_MODULE(spat){
 		.method("global", &SpatRaster::global, "global")
 		.method("initf", ( SpatRaster (SpatRaster::*)(std::string, bool, SpatOptions&) )( &SpatRaster::init ), "init fun")
 		.method("initv", ( SpatRaster (SpatRaster::*)(double, SpatOptions&) )( &SpatRaster::init ), "init value")
+		.method("isnan", &SpatRaster::isnan, "isnan")
+		.method("isfinite", &SpatRaster::isfinite, "isfinite")
+		.method("isinfinite", &SpatRaster::isinfinite, "isinfinite")
 		.method("logic_rast", ( SpatRaster (SpatRaster::*)(SpatRaster, std::string, SpatOptions&) )( &SpatRaster::logic ))
 		.method("logic_numb", ( SpatRaster (SpatRaster::*)(bool, std::string, SpatOptions&) )( &SpatRaster::logic ))
 		.method("mask_raster", ( SpatRaster (SpatRaster::*)(SpatRaster, bool, double, double, SpatOptions&) )( &SpatRaster::mask), "mask raster")
-		.method("mask_vector", ( SpatRaster (SpatRaster::*)(SpatVector, bool, double, double, SpatOptions&) )( &SpatRaster::mask), "mask vector")	
+		.method("mask_vector", ( SpatRaster (SpatRaster::*)(SpatVector, bool, double, SpatOptions&) )( &SpatRaster::mask), "mask vector")	
 		.method("math", &SpatRaster::math, "math")
 		.method("math2", &SpatRaster::math2, "math2")
 		.method("modal", &SpatRaster::modal, "modal")
 		.method("quantile", &SpatRaster::quantile, "quantile")
 		.method("rasterize", &SpatRaster::rasterize, "rasterize")
 		.method("rotate", &SpatRaster::rotate, "rotate")
-		.method("sampleRegular", &SpatRaster::sampleRegular, "sampleRegular")	
-		.method("sampleRandom", &SpatRaster::sampleRandom, "sampleRandom")	
+		.method("sampleRegularRaster", &SpatRaster::sampleRegularRaster, "sampleRegular")	
+		.method("sampleRegularValues", &SpatRaster::sampleRegularValues, "sampleValues")	
+		.method("sampleRandomRaster", &SpatRaster::sampleRandomRaster, "sampleRandom")	
+		.method("sampleRandomValues", &SpatRaster::sampleRandomValues, "sampleValues")	
 		.method("shift", &SpatRaster::shift, "shift")
 		.method("slope", &SpatRaster::slope, "slope")
 		.method("summary", &SpatRaster::summary, "summary")
