@@ -6,6 +6,8 @@ SpatMessages can_write(std::string filename, bool overwrite);
 std::string getFileExt(const std::string& s);
 std::string setFileExt(const std::string& s, const std::string& ext);
 std::string basename(std::string filename);
+std::string basename_noext(std::string filename);
+std::string noext(std::string filename);
 std::string tempFile(std::string tmpdir, std::string ext);
 
 #endif
