@@ -1,4 +1,4 @@
-// Copyright (c) 2018-2019  Robert J. Hijmans
+// Copyright (c) 2018-2020  Robert J. Hijmans
 //
 // This file is part of the "spat" library.
 //
@@ -21,12 +21,13 @@
 #include <cmath>
 #include "spatMessages.h"
 
-// comment out if this is not for R (no Rcpp)
-#define useRcpp
-// comment out if GDAL is not available
+#ifndef standalone
+	#define useRcpp
+#endif
+
 #define useGDAL
-// comment out if GEOS is not available
-#define useGEOS
+//#define useGEOS
+
 
 #ifndef M_PI
 #define M_PI (3.14159265358979323846)
