@@ -1,4 +1,4 @@
-// Copyright (c) 2018-2019  Robert J. Hijmans
+// Copyright (c) 2018-2020  Robert J. Hijmans
 //
 // This file is part of the "spat" library.
 //
@@ -22,9 +22,7 @@
 #ifdef useGDAL
 #include "gdal_priv.h"
 #endif
-
 #ifdef useRcpp
-
 #include <Rcpp.h>
 // Rcpp::depends(RcppProgress)
 #include "progress.hpp"
@@ -123,6 +121,8 @@ class SpatRaster {
 
 	public:
 
+	//	bool GDALregistred = false;
+
 #ifdef useRcpp
 		Progress* pbar;
 #endif
@@ -207,7 +207,7 @@ class SpatRaster {
 
 		bool constructFromFile(std::string fname);
 		bool constructFromFiles(std::vector<std::string> fnames);
-		bool constructFromFileGDAL(std::string fname);
+		//bool constructFromFileGDAL(std::string fname);
 		bool constructFromSubDataSets(std::string filename, std::vector<std::string> sds);
 
 		void addSource(SpatRaster x);
@@ -356,8 +356,8 @@ class SpatRaster {
 		std::vector<std::vector<double>> extractCell(std::vector<double> &cell);
         std::vector<std::vector<double>> extractXY(std::vector<double> &x, std::vector<double> &y, std::string method);
 		SpatRaster flip(bool vertical, SpatOptions &opt);
-		SpatRaster focal(std::vector<double> w, double fillvalue, bool narm, std::string fun, SpatOptions &opt);
-		std::vector<double> focal_values(std::vector<unsigned> w, double fillvalue, unsigned row, unsigned nrows);
+		SpatRaster focal(std::vector<unsigned> w, std::vector<double> m, double fillvalue, bool narm, std::string fun, SpatOptions &opt);
+		std::vector<double> focal_values(std::vector<unsigned> w, double fillvalue, int row, int nrows);
 		std::vector<std::vector<double>> freq(bool bylayer);
 		bool get_aggregate_dims(std::vector<unsigned> &fact, std::string &message);
 		std::vector<unsigned> get_aggregate_dims2(std::vector<unsigned> fact);
@@ -370,11 +370,15 @@ class SpatRaster {
 		SpatRaster init(std::string value, bool plusone, SpatOptions &opt);
 		SpatRaster init(double value, SpatOptions &opt);
 		SpatRaster isnot(SpatOptions &opt);
-        std::vector<double> line_cells(SpatGeom& g);
+		SpatRaster isnan(SpatOptions &opt);
+		SpatRaster isfinite(SpatOptions &opt);
+		SpatRaster isinfinite(SpatOptions &opt);
+        
+		std::vector<double> line_cells(SpatGeom& g);
 		SpatRaster logic(SpatRaster x, std::string oper, SpatOptions &opt);
 		SpatRaster logic(bool x, std::string oper, SpatOptions &opt);
 		SpatRaster mask(SpatRaster x, bool inverse, double maskvalue, double updatevalue, SpatOptions &opt);
-		SpatRaster mask(SpatVector x, bool inverse, double maskvalue, double updatevalue, SpatOptions &opt);
+		SpatRaster mask(SpatVector x, bool inverse, double updatevalue, SpatOptions &opt);
 		SpatRaster math(std::string fun, SpatOptions &opt);
 		SpatRaster math2(std::string fun, unsigned digits, SpatOptions &opt);
 
@@ -393,11 +397,13 @@ class SpatRaster {
 		std::vector<double> readSample(unsigned src, unsigned srows, unsigned scols);
 		SpatRaster rotate(bool left, SpatOptions &opt);
 
-		SpatRaster sampleRegular(unsigned size);
-		std::vector<std::vector<double>> sampleRandom(unsigned size, bool replace, unsigned seed);
-		
+		SpatRaster sampleRegularRaster(unsigned size);
+		SpatRaster sampleRandomRaster(unsigned size, bool replace, unsigned seed);
+		std::vector<std::vector<double>> sampleRegularValues(unsigned size);
+		std::vector<std::vector<double>> sampleRandomValues(unsigned size, bool replace, unsigned seed);
+
 		SpatRaster slope(unsigned neighbors, bool degrees, SpatOptions &opt);
-	
+
 		SpatRaster collapse(SpatRaster x, SpatOptions &opt);
 
 		SpatRaster shift(double x, double y, SpatOptions &opt);
